@@ -509,6 +509,38 @@ our $charset = {
 @subs = (
 
 
+					#######################################
+
+	{
+		name     => 'get_request',
+		label_en => 'Set up $r and $apr. Internal use only.',
+		label_ru => '    $r  $apr    handler.    .',
+	},
+
+					#######################################
+
+	{
+		name     => 'get_version_name',
+		label_en => 'Returns the same as $Zanas::VERSION_NAME.',
+		label_ru => ' ( )  $Zanas::VERSION_NAME.',
+	},
+
+					#######################################
+
+	{
+		name     => 'sql_assert_core_tables',
+		label_en => 'Guarantees the existence of core tables in the DB. Internal use only.',
+		label_ru => '    ,    Zanas.    .',
+	},
+
+					#######################################
+
+	{
+		name     => 'format_picture',
+		label_en => 'Wrap around Number::Format -> format_picture hiding the number when $_USER -> {demo_level} > 1.',
+		label_ru => '-  Number::Format -> format_picture,    $_USER -> {demo_level} > 1.',
+	},
+
 
 					#######################################
 
@@ -2551,6 +2583,13 @@ our @conf = (
 		see_also => [qw(format_dt)],
 	},
 
+	{
+		name => 'number_format',
+		label_en => 'Number::Format options',
+		label_ru => '   Number::Format.   -thousands_sep  -decimal_point.',
+		see_also => [qw(format_dt)],
+	},
+
 	{
 		name => 'format_dt',
 		label_en => 'Default date format for calendar input field',
